package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SiteConfig;

/**
 * 系统配置Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface ISiteConfigService 
{
    /**
     * 查询系统配置
     * 
     * @param id 系统配置主键
     * @return 系统配置
     */
    public SiteConfig selectSiteConfigById(Integer id);

    /**
     * 查询系统配置列表
     * 
     * @param siteConfig 系统配置
     * @return 系统配置集合
     */
    public List<SiteConfig> selectSiteConfigList(SiteConfig siteConfig);

    /**
     * 新增系统配置
     * 
     * @param siteConfig 系统配置
     * @return 结果
     */
    public int insertSiteConfig(SiteConfig siteConfig);

    /**
     * 修改系统配置
     * 
     * @param siteConfig 系统配置
     * @return 结果
     */
    public int updateSiteConfig(SiteConfig siteConfig);

    /**
     * 批量删除系统配置
     * 
     * @param ids 需要删除的系统配置主键集合
     * @return 结果
     */
    public int deleteSiteConfigByIds(Integer[] ids);

    /**
     * 删除系统配置信息
     * 
     * @param id 系统配置主键
     * @return 结果
     */
    public int deleteSiteConfigById(Integer id);
}
